//
// Lookup.c
//
// This file shows you how to call ZipCode+ Lookup from a program of your
// own. You will need to have both ZipCode+ and its database installed.
// (The database can be tailored by deleting states, as required.) You
// will also need to have a license for each copy of ZipCode+ in use.
//
// The procedure for invoking ZipCode+ Lookup is pretty simple. If you
// have any problems, email me. I'd also like to hear from you (and
// about your application) if you do use this interface.
//
//    Stephen Best
//    Bitware Australia Pty. Ltd.
//
//    info@bitwareoz.com
//    www.bitwareoz.com
//
//    February 10, 1999
//

#include <Pilot.h>

//
// This is the lookup data structure. It could be on the stack or
// allocated from the heap. If on the heap, it must be locked.
//

typedef struct
   {
   ULong           caller;            // CRID of caller (currently ignored)
   Boolean         update;            // Set to true on return if changed
   Char            data [120];        // Packed ASCIIZ strings
   } ZipcodeLookupType, *ZipcodeLookupPtr;

//
// Below is a sample function for calling ZipCode+ Lookup. You can provide
// any or all of the city/county/state/zipcode fields and ZipCode+ Lookup
// will try to figure out the most suitable context. (Note that currently
// the county is ignored on input, but it will be returned.) The data area
// of the structure is filled with packed ASCIIZ strings. Field text can
// be upper or lower case. For fields not provided, insert a null string
// in the input stream. Some examples:
// 
//    Staten Island\0\0NY\0\0
//    \0\0\010301\0
//    staten\0\0New York\0\0
//    S\0\0\010301-1234\0
//
// The results are returned in the same area with the update flag set true
// if a Paste was selected (and unchanged for a Cancel). Example:
//
//    Staten Island\0Richmond\0NY\010301\0
//    Staten Island\0Richmond\0New York\010314\0
//
// You should, of course, ensure that all the fields fit in the allocated
// data space.
//

Boolean ZipcodeLookup
   (
   CharPtr          cityPtr,          // City (or prefix)
   CharPtr          countyPtr,        // County (ignored on input)
   CharPtr          statePtr,         // State - abbreviation or full name
   CharPtr          zipcodePtr        // Zip Code - 5 digit or Zip+4
   )
   
   {
   ZipcodeLookupType   lookup;        // Lookup parameters
   CharPtr         dataPtr;           // Current pointer in data area

         // Set caller's CreatorID

   lookup.caller = 'MYID';            // CRID of calling application
   
         // Set update flag
         
   lookup.update = false;             // Indicate unchanged
   
         // Copy city, county, state, zipcode to lookup structure
         
   dataPtr = lookup.data;
   
   StrCopy (dataPtr, cityPtr);
   
   dataPtr += StrLen (dataPtr) + 1;
   
   StrCopy (dataPtr, countyPtr);
   
   dataPtr += StrLen (dataPtr) + 1;
   
   StrCopy (dataPtr, statePtr);
   
   dataPtr += StrLen (dataPtr) + 1;
   
   StrCopy (dataPtr, zipcodePtr);
   
         // Invoke ZipCode+ Lookup (BWA3 is ZipCode+)
      
   AppCallWithCommand ('BWA3', sysAppLaunchCmdLookup, &lookup);
   
         // If changed, retrieve updated fields
   
   if ( lookup.update )
      {
      dataPtr = lookup.data;
      
      StrCopy (cityPtr, dataPtr);
      
      dataPtr += StrLen (dataPtr) + 1;
      
      StrCopy (countyPtr, dataPtr);
      
      dataPtr += StrLen (dataPtr) + 1;
      
      StrCopy (statePtr, dataPtr);
      
      dataPtr += StrLen (dataPtr) + 1;
      
      StrCopy (zipcodePtr, dataPtr);
      }

         // Return true if field contents changed
               
   return lookup.update;
   }
